@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2013 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2014 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,6 +17,7 @@
 */
 
 #include "myprocess.h"
+#include <QDebug>
 
 #ifdef Q_OS_WIN
 
@@ -158,14 +159,14 @@ void MyProcess::procFinished() {
 	qDebug("MyProcess::procFinished");
 
 #if !USE_TEMP_FILE
-	qDebug("MyProcess::procFinished: Bytes available: %ld", bytesAvailable());
+	qDebug() << "MyProcess::procFinished: Bytes available: " << bytesAvailable();
 	if ( bytesAvailable() > 0 ) readStdOut();
 #else
 	timer.stop();
 
-	qDebug("MyProcess::procFinished: Bytes available: %ld", temp_file.bytesAvailable());
+	qDebug() << "MyProcess::procFinished: Bytes available: " << temp_file.bytesAvailable();
 	if ( temp_file.bytesAvailable() > 0 ) readTmpFile();
-	qDebug("MyProcess::procFinished: Bytes available: %ld", temp_file.bytesAvailable());
+	qDebug() << "MyProcess::procFinished: Bytes available:" << temp_file.bytesAvailable();
 
 	temp_file.close();
 #endif
