@@ -215,7 +215,10 @@ void Preferences::reset() {
 
 #ifdef YOUTUBE_SUPPORT
 	yt_quality = RetrieveYoutubeUrl::MP4_720p;
-	yt_user_agent = QString::null;
+	//yt_user_agent = "Mozilla/5.0 (X11; Linux x86_64; rv:5.0.1) Gecko/20100101 Firefox/5.0.1";
+	yt_user_agent = "";
+	yt_use_https_main = false;
+	yt_use_https_vi = false;
 #endif
 
 
@@ -390,6 +393,10 @@ void Preferences::reset() {
 
 	close_on_finish = false;
 
+#ifdef AUTO_SHUTDOWN_PC
+	auto_shutdown_pc = false;
+#endif
+
 	default_font = "";
 
 	pause_when_hidden = false;
@@ -680,6 +687,8 @@ void Preferences::save() {
 	set->beginGroup("youtube");
 	set->setValue("quality", yt_quality);
 	set->setValue("user_agent", yt_user_agent);
+	set->setValue("yt_use_https_main", yt_use_https_main);
+	set->setValue("yt_use_https_vi", yt_use_https_vi);
 	set->endGroup();
 #endif
 
@@ -846,6 +855,10 @@ void Preferences::save() {
 
 	set->setValue("close_on_finish", close_on_finish);
 
+#ifdef AUTO_SHUTDOWN_PC
+	set->setValue("auto_shutdown_pc", auto_shutdown_pc);
+#endif
+
 	set->setValue("default_font", default_font);
 
 	set->setValue("pause_when_hidden", pause_when_hidden);
@@ -1169,6 +1182,8 @@ void Preferences::load() {
 	set->beginGroup("youtube");
 	yt_quality = set->value("quality", yt_quality).toInt();
 	yt_user_agent = set->value("user_agent", yt_user_agent).toString();
+	yt_use_https_main = set->value("yt_use_https_main", yt_use_https_main).toBool();
+	yt_use_https_vi = set->value("yt_use_https_vi", yt_use_https_vi).toBool();
 	set->endGroup();
 #endif
 
@@ -1342,6 +1357,10 @@ void Preferences::load() {
 
 	close_on_finish = set->value("close_on_finish", close_on_finish).toBool();
 
+#ifdef AUTO_SHUTDOWN_PC
+	auto_shutdown_pc = set->value("auto_shutdown_pc", auto_shutdown_pc).toBool();
+#endif
+
 	default_font = set->value("default_font", default_font).toString();
 
 	pause_when_hidden = set->value("pause_when_hidden", pause_when_hidden).toBool();
